@@ -3,4 +3,5 @@ from ._commands import (command_creator,
                         measurement_unpacker,
                         Opcode,
                         Shifts)
-from ._hardware_abstraction_layer_node import HardwareAbstractionLayerNode
+from ._hardware_abstraction_layer_node import (HardwareAbstractionLayerNode,
+                                               hal_template)
