@@ -1,5 +1,4 @@
 import unittest
-from collections import OrderedDict
 
 from deltalanguage.lib import StateSaver
 from deltalanguage.runtime import DeltaPySimulator, DeltaRuntimeExit
@@ -16,22 +15,22 @@ from deltalanguage.wiring._node_classes.node_bodies import PyMigenBody
 
 test_template1 = NodeTemplate(name="AdderTemplate",
                               inputs=[('a', int), ('b', int)],
-                              outputs=int)
+                              outputs=[('output', int)])
 
 
-@DeltaBlock(test_template1, allow_const=False)
+@DeltaBlock(template=test_template1, allow_const=False)
 def simple_add(a: int, b: int) -> int:
     return a + b
 
 
-@DeltaBlock(test_template1, allow_const=False)
+@DeltaBlock(template=test_template1, allow_const=False)
 def over_complex_add(a: int, b: int) -> int:
     return 2*a + 2*b - a - b
 
 
 @Interactive(template=test_template1,
              inputs=[('a', int), ('b', int)],
-             outputs=int)
+             outputs=[('output', int)])
 def broken_adder(node: RealNode):
     a = node.receive('a')
     b = node.receive('b')
@@ -43,7 +42,7 @@ class OpCacher():
     def __init__(self):
         self._add_cache = {}
 
-    @DeltaMethodBlock(test_template1)
+    @DeltaMethodBlock(template=test_template1)
     def cached_add(self, a: int, b: int) -> int:
         if (a, b) in self._add_cache:
             return self._add_cache[(a, b)]
@@ -90,11 +89,6 @@ class NodeTempalteViaDecoratorsTest(unittest.TestCase):
         self.assertEqual([5], saver.saved)
 
 
-m_template = NodeTemplate(name="MTemplate",
-                          inputs=[('a', int), ('b', int)],
-                          outputs=int)
-
-
 class AMigenNode(MigenNodeTemplate):
     def migen_body(self, template):
         template.add_pa_in_port('a', Optional(int))
@@ -114,8 +108,8 @@ class NodeTemplateViaMigenClass(unittest.TestCase):
                     ('b', Optional(int))]
         )
 
-        @DeltaBlock(m_template, allow_const=False)
-        def m_simple_add(a: Optional(int), b: Optional(int)):
+        @DeltaBlock(template=m_template, allow_const=False)
+        def _m_simple_add(a: Optional(int), b: Optional(int)):
             raise DeltaRuntimeExit
 
         m_maker = AMigenNode(node_template=m_template)
@@ -211,32 +205,32 @@ class NodeTemplateAddConstructor(unittest.TestCase):
     """
 
     def test_add_func(self):
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_a = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
         @DeltaBlock(allow_const=False)
         def simple_add_2(a: int, b: int) -> int:
             return a + b
 
-        test_template1.add_constructor(simple_add_2)
+        test_template_a.add_constructor(simple_add_2)
 
         with DeltaGraph():
-            n1 = test_template1.call(2, 3)
+            n1 = test_template_a.call(2, 3)
 
         self.assertEqual(len(n1.bodies), 1)
         self.assertIn('simple_add_2', n1.body.access_tags)
 
     def test_add_method(self):
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_b = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
-        @DeltaBlock(template=test_template1, allow_const=False)
-        def simple_add_2(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template_b, allow_const=False)
+        def _simple_add_2(a: int, b: int) -> int:
             return a + b
 
-        test_template1.add_constructor(OpCacher2.cached_add_2)
+        test_template_b.add_constructor(OpCacher2.cached_add_2)
 
         with DeltaGraph():
             n1 = OpCacher2().cached_add_2(2, 3)
@@ -245,36 +239,36 @@ class NodeTemplateAddConstructor(unittest.TestCase):
         self.assertIn('cached_add_2', n1.body.access_tags)
 
     def test_add_interactive(self):
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_c = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
         @Interactive(inputs=[('a', int), ('b', int)],
-                     outputs=int)
+                     outputs=[('output', int)])
         def broken_adder_2(node: RealNode):
             a = node.receive('a')
             b = node.receive('b')
             node.send(a+b+1)
 
-        test_template1.add_constructor(broken_adder_2)
+        test_template_c.add_constructor(broken_adder_2)
 
         with DeltaGraph():
-            n1 = test_template1.call(2, 3)
+            n1 = test_template_c.call(2, 3)
 
         self.assertEqual(len(n1.bodies), 1)
         self.assertIn('broken_adder_2', n1.body.access_tags)
 
     def test_add_migen(self):
-        test_template1 = NodeTemplate(
+        test_template_d = NodeTemplate(
             name="test_1",
             inputs=[('a', Optional(int)),
                     ('b', Optional(int))]
         )
 
-        test_template1.add_constructor(AMigenNode2())
+        test_template_d.add_constructor(AMigenNode2())
 
         with DeltaGraph():
-            n1 = test_template1.call(2, 3)
+            n1 = test_template_d.call(2, 3)
 
         self.assertEqual(len(n1.bodies), 1)
         self.assertIn(PyMigenBody, n1.body.access_tags)
@@ -283,22 +277,22 @@ class NodeTemplateAddConstructor(unittest.TestCase):
         """Test for when the constructor we are adding is already associated
         with some other ``NodeTemplate``.
         """
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_e = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
-        test_template2 = NodeTemplate(name="test_2",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_f = NodeTemplate(name="test_2",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
-        @DeltaBlock(test_template2, allow_const=False)
+        @DeltaBlock(template=test_template_f, allow_const=False)
         def simple_add_2(a: int, b: int) -> int:
             return a + b
 
-        test_template1.add_constructor(simple_add_2)
+        test_template_e.add_constructor(simple_add_2)
 
         with DeltaGraph():
-            n1 = test_template1.call(2, 3)
+            n1 = test_template_e.call(2, 3)
 
         self.assertEqual(len(n1.bodies), 1)
         self.assertIn('simple_add_2', n1.body.access_tags)
@@ -307,33 +301,33 @@ class NodeTemplateAddConstructor(unittest.TestCase):
         """Test for when the constructor we are adding is already on the
         ``NodeTemplate``. The constructor should not be added twice.
         """
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_g = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
-        @DeltaBlock(test_template1, allow_const=False)
+        @DeltaBlock(template=test_template_g, allow_const=False)
         def simple_add_2(a: int, b: int) -> int:
             return a + b
 
-        test_template1.add_constructor(simple_add_2)
+        test_template_g.add_constructor(simple_add_2)
 
         with DeltaGraph():
-            n1 = test_template1.call(2, 3)
+            n1 = test_template_g.call(2, 3)
 
         self.assertEqual(len(n1.bodies), 1)
         self.assertIn('simple_add_2', n1.body.access_tags)
 
     def test_add_invalid_constructor(self):
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_h = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
         @DeltaBlock(allow_const=False)
         def simple_add_to_bool(a: int, b: int) -> bool:
             return bool(a + b)
 
         with self.assertRaises(ValueError):
-            test_template1.add_constructor(simple_add_to_bool)
+            test_template_h.add_constructor(simple_add_to_bool)
 
 
 class InvalidNodeTemplate(unittest.TestCase):
@@ -347,15 +341,15 @@ class InvalidNodeTemplate(unittest.TestCase):
         """
         test_template2 = NodeTemplate(name="test",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
         with self.assertRaises(ValueError):
-            @DeltaBlock(test_template2, allow_const=False)
+            @DeltaBlock(template=test_template2, allow_const=False)
             def _test1(a: int, b: bool) -> int:
                 return a + b
 
         with self.assertRaises(ValueError):
-            @DeltaBlock(test_template2, allow_const=False)
+            @DeltaBlock(template=test_template2, allow_const=False)
             def _test2(wrong_name: int, b: int) -> int:
                 return wrong_name + b
 
@@ -366,16 +360,16 @@ class InvalidNodeTemplate(unittest.TestCase):
         test_template2 = NodeTemplate(
             name="test",
             inputs=[('a', Optional(int)), ('b', Optional(int))],
-            outputs=int
+            outputs=[('output', int)]
         )
 
         with self.assertRaises(ValueError):
-            @DeltaBlock(test_template2, allow_const=False)
+            @DeltaBlock(template=test_template2, allow_const=False)
             def _test1(a: Optional(int), b: int) -> int:
                 return a + b
 
         with self.assertRaises(ValueError):
-            @ DeltaBlock(test_template2, allow_const=False)
+            @ DeltaBlock(template=test_template2, allow_const=False)
             def _test2(wrong_name: int, b: int) -> int:
                 return wrong_name + b
 
@@ -385,10 +379,10 @@ class InvalidNodeTemplate(unittest.TestCase):
         """
         test_template2 = NodeTemplate(name="test",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
         with self.assertRaises(ValueError):
-            @DeltaBlock(test_template2, allow_const=False)
+            @DeltaBlock(template=test_template2, allow_const=False)
             def _test1(a: int, b: int) -> bool:
                 return a + b
 
@@ -400,16 +394,16 @@ class NodeTemplateMerge(unittest.TestCase):
 
     def __init__(self, methodName):
         super().__init__(methodName)
-        test_template1 = NodeTemplate(name="test_1",
-                                      inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+        test_template_x = NodeTemplate(name="test_1",
+                                       inputs=[('a', int), ('b', int)],
+                                       outputs=[('output', int)])
 
-        @DeltaBlock(test_template1, allow_const=False)
-        def simple_add(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template_x, allow_const=False)
+        def simple_add_2(a: int, b: int) -> int:
             return a + b
 
-        self.template_1_body = simple_add.template
-        self.test_template1 = test_template1
+        self.template_1_body = simple_add_2.template
+        self.test_template1 = test_template_x
 
     def test_merge_adds_bodies(self):
         """Test to ensure in params must match when associating
@@ -417,24 +411,24 @@ class NodeTemplateMerge(unittest.TestCase):
         """
         test_template3 = NodeTemplate(name="test_3",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
-        @DeltaBlock(test_template3, allow_const=False)
-        def simple_add(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template3, allow_const=False)
+        def simple_add_2(a: int, b: int) -> int:
             return a + b
 
         test_template2 = NodeTemplate(name="test_2",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
-        @DeltaBlock(test_template2, allow_const=False)
-        def simple_add_2(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template2, allow_const=False)
+        def simple_add_3(a: int, b: int) -> int:
             return a + b
 
         test_template3.merge(test_template2)
         self.assertEqual(len(test_template3._body_templates), 2)
-        self.assertIn(simple_add.template, test_template3._body_templates)
         self.assertIn(simple_add_2.template, test_template3._body_templates)
+        self.assertIn(simple_add_3.template, test_template3._body_templates)
 
     def test_merge_use_in_graph(self):
         """Test to ensure in params must match when associating
@@ -442,31 +436,31 @@ class NodeTemplateMerge(unittest.TestCase):
         """
         test_template3 = NodeTemplate(name="test_3",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
-        @DeltaBlock(test_template3, allow_const=False)
-        def simple_add(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template3, allow_const=False)
+        def _simple_add_2(a: int, b: int) -> int:
             return a + b
 
         test_template2 = NodeTemplate(name="test_2",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
-        @DeltaBlock(test_template2, allow_const=False)
-        def simple_add_2(a: int, b: int) -> int:
+        @DeltaBlock(template=test_template2, allow_const=False)
+        def simple_add_3(a: int, b: int) -> int:
             return a + b
 
         test_template3.merge(test_template2)
 
         saver = StateSaver()
         with DeltaGraph() as graph:
-            n1 = simple_add_2(4, 73)
+            n1 = simple_add_3(4, 73)
             saver.save_and_exit(n1)
 
         self.assertEqual(len(n1.bodies), 2)
 
-        graph.select_bodies(preferred=['simple_add'])
-        self.assertIn("simple_add", n1.body.access_tags)
+        graph.select_bodies(preferred=['_simple_add_2'])
+        self.assertIn("_simple_add_2", n1.body.access_tags)
         DeltaPySimulator(graph).run()
         self.assertEqual([77], saver.saved)
 
@@ -476,7 +470,7 @@ class NodeTemplateMerge(unittest.TestCase):
         """
         test_template2 = NodeTemplate(name="test_2",
                                       inputs=[('a', int), ('c', int)],
-                                      outputs=int)
+                                      outputs=[('output', int)])
 
         with self.assertRaises(ValueError):
             self.test_template1.merge(test_template2)
@@ -490,7 +484,7 @@ class NodeTemplateMerge(unittest.TestCase):
         """
         test_template2 = NodeTemplate(name="test_2",
                                       inputs=[('a', int), ('b', int)],
-                                      outputs=bool)
+                                      outputs=[('output', bool)])
 
         with self.assertRaises(ValueError):
             self.test_template1.merge(test_template2)
